<p align="center">
  <img src="menpowidgets-logo.png" alt="menpo" width="30%"></center>
  <br><br>
  <a href="https://github.com/menpo/menpowidgets/blob/master/LICENSE.txt"><img src="http://img.shields.io/badge/License-BSD-green.svg" alt="BSD License"/></a>
  <img src="https://img.shields.io/badge/Python-2.7-green.svg" alt="Python 2.7 Support"/>
  <img src="https://img.shields.io/badge/Python-3.4-green.svg" alt="Python 3.4 Support"/>
  <img src="https://img.shields.io/badge/Python-3.5-green.svg" alt="Python 3.5 Support"/>
</p>


menpowidgets - Jupyter widgets for fancy visualization
======================================================

What is MenpoWidgets?
---------------------
MenpoWidgets is the [Menpo Project](http://www.menpo.org/)'s Python package for fancy visualization within the Jupyter notebook using interactive widgets.
In the [Menpo Project](http://www.menpo.org/) we take an opinionated stance that visualization is a key part of generating research. Therefore, we have tried
to make the mental overhead of visualizing objects as low as possible. MenpoWidgets makes tasks like data exploration, model observation
and results demonstration as simple as possible.

Installation
------------
Unfortunately, the Menpo Project is a complex project that relies on satisfying
a number of complex 3rd party library dependencies. The default Python packing
environment does not make this an easy task. Therefore, we evangelise the use
of the conda ecosystem, provided by
[Anaconda](https://store.continuum.io/cshop/anaconda/). In order to make things
as simple as possible, we suggest that you use conda too! To try and persuade
you, go to the [Menpo website](http://www.menpo.org/installation/) to find
installation instructions for all major platforms.

API Documentation
-----------------
In MenpoWidgets, we use legible docstrings, and therefore, all documentation
should be easily accessible in any sensible IDE (or IPython) via tab completion.
However, we strongly advise you to visit the [MenpoWidgets API documentation](http://menpowidgets.readthedocs.io/).
